@@ -28,31 +28,33 @@ getOmega <- function(data, p, M, params, StMAR=FALSE, GStMAR=FALSE, restricted=F
                       conditional=FALSE, checks=FALSE, returnTerms=TRUE)
   }
 
-  diff = 1e-08 # Difference for numerical derivates
-  d = length(params) # Dimension of the parameter vector
-  dataSize = length(data) # Size of the given data
+  diff <- 6e-06 # Difference for numerical derivates
+  d <- length(params) # Dimension of the parameter vector
+  dataSize <- length(data) # Size of the given data
   if(missing(qresiduals)) {
-    qresiduals = quantileResiduals_int(data, p, M, params, StMAR=StMAR, GStMAR=GStMAR, restricted=restricted, constraints=constraints, R=R) # Quantile residuals
+    qresiduals <- quantileResiduals_int(data, p, M, params, StMAR=StMAR, GStMAR=GStMAR, restricted=restricted, constraints=constraints, R=R) # Quantile residuals
   }
 
   # Compute the gradient of g: (v)x(d)x(T)
-  T0 = nrow(f(params))
+  T0 <- nrow(f(params))
 
-  I = diag(rep(1, d))
-  dg = array(dim=c(dim_g, d, T0))  # row per g_i, column per derivative and slice per t=1,..,T.
+  I <- diag(rep(1, d))
+  dg <- array(dim=c(dim_g, d, T0))  # row per g_i, column per derivative and slice per t=1,..,T.
   for(i1 in 1:d) {
-    dg[,i1,] = t((f(params+I[i1,]*diff)-f(params-I[i1,]*diff))/(2*diff))
+    dg[,i1,] <- t((f(params+I[i1,]*diff)-f(params-I[i1,]*diff))/(2*diff))
   }
 
   # Compute gradient of the log-likelihood: (T)x(d)
-  dl = sapply(1:d, function(i1) (l(params+I[,i1]*diff)-l(params-I[,i1]*diff))/(2*diff)) # NOTE: "returnTerms" in loglik is TRUE
+  dl <- vapply(1:d, function(i1) (l(params+I[,i1]*diff)-l(params-I[,i1]*diff))/(2*diff), numeric(dataSize-p)) # NOTE: "returnTerms" in loglik is TRUE
 
-  # Estimate Fisher's information matrix
-  FisInf <- matrix(0, ncol=d, nrow=d)
-  for(i1 in 1:T0) {
-    FisInf = FisInf + tcrossprod(dl[i1,], dl[i1,])
-  }
-  FisInf = FisInf/(dataSize-p)
+ # Estimate Fisher's information matrix
+ # FisInf <- matrix(0, ncol=d, nrow=d)
+ # for(i1 in 1:nrow(dl)) {
+ #   FisInf <- FisInf + tcrossprod(dl[i1,], dl[i1,])
+ # }
+ # FisInf <- FisInf/(dataSize-p)
+
+  FisInf <- crossprod(dl, dl)/nrow(dl)
 
   invFisInf <- tryCatch(solve(FisInf), error=function(cond) {
     message("The covariance matrix Omega cannot be solved")
@@ -63,17 +65,20 @@ getOmega <- function(data, p, M, params, StMAR=FALSE, GStMAR=FALSE, restricted=F
   }
 
   # Calculate G (Kalliovirta 2012 eq.(2.4))
-  G = apply(dg, c(1,2), mean)
+#  G <- apply(dg, c(1,2), mean)
+  G <- rowMeans(dg, dims=2)
 
   # Calculate PSI
-  gres = t(g(qresiduals))
-  dif0 = nrow(dl)-T0
-  PSI = gres%*%dl[(dif0+1):nrow(dl),]/T0
+#  gres <- t(g(qresiduals))
+  gres <- g(qresiduals)
+  dif0 <- nrow(dl) - T0
+#  PSI <- gres%*%dl[(dif0+1):nrow(dl),]/T0
+  PSI <- crossprod(gres, dl[(dif0+1):nrow(dl),])/T0
 
   # Calculate H
-  H = gres%*%t(gres)/T0
+  H <- crossprod(gres, gres)/T0
 
   # Calculate Omega
-  Omega = G%*%invFisInf%*%t(G) + PSI%*%invFisInf%*%t(G) + G%*%invFisInf%*%t(PSI) + H
+  Omega <- G%*%tcrossprod(invFisInf, G) + PSI%*%tcrossprod(invFisInf, G) + G%*%tcrossprod(invFisInf, PSI) + H
   return(Omega)
 }
